/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGHTMLBOARDWIDGET_H
#define SKGHTMLBOARDWIDGET_H
/** @file
* This file is a generic Skrooge plugin for html reports.
* @see SKGReport
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/
#include "skgboardwidget.h"
#include "skgbasegui_export.h"

class QLabel;
class SKGSimplePeriodEdit;

/**
 * This file is a generic Skrooge plugin for html reports
 */
class SKGBASEGUI_EXPORT SKGHtmlBoardWidget : public SKGBoardWidget
{
    Q_OBJECT
    /**
     * This enumerate for additional options in menu
     */
    Q_ENUMS(AdditionalOption)
public:
    /**
     * This enumerate for additional options in menu
     */
    enum AdditionalOption {NONE,   /**< No additional option */
                           PERIOD_ONLY_MONTHS, /**< Add period selector with only months*/
                           PERIOD_ALL /**< Add period selector with months, quarters, semesters and years*/
                          };

    /**
     * Default Constructor
     * @param iDocument the document
     * @param iTitle the title
     * @param iTemplate the html template
     * @param iTablesRefreshing the list of table refreshing the report when the table is updated. (empty means all)
     * @param iOptions to enable options in menu
     */
    explicit SKGHtmlBoardWidget(SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, const QStringList& iTablesRefreshing = QStringList(), AdditionalOption iOptions = SKGHtmlBoardWidget::NONE);

    /**
     * Default Destructor
     */
    virtual ~SKGHtmlBoardWidget();

    /**
     * Get the current state
     * MUST BE OVERWRITTEN
     * @return a string containing all information needed to set the same state.
     * Could be an XML stream
     */
    virtual QString getState() Q_DECL_OVERRIDE;

    /**
     * Set the current state
     * MUST BE OVERWRITTEN
     * @param iState must be interpreted to set the state of the widget
     */
    virtual void setState(const QString& iState) Q_DECL_OVERRIDE;

protected Q_SLOTS:
    void pageChanged();
    void dataModified(const QString& iTableName = QString(), int iIdTransaction = 0);

private:
    Q_DISABLE_COPY(SKGHtmlBoardWidget)

    QLabel* m_Text;
    QLabel* m_Title;
    QString m_HtmlTemplate;
    QStringList m_TablesRefreshing;
    bool m_refreshNeeded;

    SKGSimplePeriodEdit* m_period;
};

#endif  // SKGHTMLBOARDWIDGET_H
